@@ -55,6 +55,13 @@ delete(__attribute__ ((unused)) Context_t *ctx)
 }
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  ctx->ref_taken = 0;
+}
+
+
 #if 0
 static unsigned char *
 image_diff_filter(unsigned char *diff)
@@ -102,16 +109,19 @@ run(Context_t *ctx)
   Pixel_t *dst;
   uint16_t x, y;
 
+  if (!ctx->has_cam)
+    return;
+
   pthread_mutex_lock(&ctx->cam_mtx);
   src1 = ctx->buffers[CAM_IN_BUFFER];
-  src2 = ctx->cam_ref;
+  src2 = ctx->buffers[CAM_REF_BUFFER];
   Buffer8_substract_y(src1, src2, MAGIC_THRESHOLD, diff);
 
   d = diff->buffer;
 
   dst += WIDTH * sizeof(Pixel_t);
   d += WIDTH * sizeof(Pixel_t);
-  src = ctx->cam_ref->buffer + (WIDTH * sizeof(Pixel_t));
+  src = ctx->buffers[CAM_REF_BUFFER]->buffer + (WIDTH * sizeof(Pixel_t));
 
   dst = passive_buffer(ctx)->buffer;
   for (y = 1; y < MAXY; y++) {
