@@ -77,9 +77,13 @@ delete(__attribute__ ((unused)) Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  int i, cf;
+  uint32_t i;
+  uint8_t cf;
   Pixel_t *dst;
   
+  if (!ctx->has_cam)
+    return;
+
   dst = passive_buffer(ctx)->buffer;
   
   pthread_mutex_lock(&ctx->cam_mtx);
