@@ -18,6 +18,7 @@
  */
 
 #include "SDL.h"
+#include "ttf.h"
 
 #define NO_MOUSE_CURSOR
 
@@ -74,36 +75,31 @@ set_cmap(Context_t *ctx)
 static inline void
 SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
 {
-  Buffer8_t *src = active_buffer(ctx);
-  u_long k = 0;
-  Pixel_t *cptr = NULL;
-  Uint32 *buf;
+  //u_long k = 0;
+  // Pixel_t *cptr = NULL;
+  //  RGBA_t *cptr = NULL;
+  //const Uint32 *buf;
+  const RGBA_t *src;
+
+  Buffer8_flip_v(active_buffer(ctx));
+  src = export_RGBA_active_buffer(ctx);
+  Buffer8_flip_v(active_buffer(ctx));
 #ifndef FIXED
   int srcstride[3] = {WIDTH*4, 0, 0};
   int dststride[3] = {out_width*4, 0, 0};
   int ret;
 
   if (bufp == NULL) {
-    bufp = xcalloc(4*BUFFSIZE, sizeof(uint8_t));
-    bufp_src[0] = bufp;
+    bufp = xcalloc(4*BUFFSIZE, sizeof(uint8_t)); /* FIXME 1*RGBA_t ? */
   }
   if (dstbufp == NULL) {
-    dstbufp = xcalloc(4*out_buffsize, sizeof(uint8_t));
+    dstbufp = xcalloc(4*out_buffsize, sizeof(uint8_t)); /* FIXME 1*RGBA_t ? */
     dstbufp_src[0] = sc->pixels;
   }
-#endif
-
-  Buffer8_copy(src, out);
-  Buffer8_flip_x(out);
-  cptr = out->buffer;
-
-#ifdef FIXED
-  buf = sc->pixels;
+  bufp_src[0] = (uint8_t *)src;
 #else
-  buf = (Uint32 *)bufp;
+  memcpy(sc->pixels, src, BUFFSIZE*sizeof(RGBA_t));
 #endif
-  for (k = 0; k < BUFFSIZE; k++)
-    *buf++ = colors[*cptr++];
 
 #ifndef FIXED
   if (NULL == sws_context)
@@ -201,6 +197,28 @@ SDL_get_event(Context_t *ctx)
 }
 
 
+static void
+osd_random_mode_elapsed(const Context_t *ctx)
+{
+  float pct = Alarm_elapsed_pct(ctx->a_random);
+  u_char color = 255; /* TODO colormap->max */
+  u_short height;
+  SDL_Rect r;
+
+#ifdef FIXED
+#define out_width  WIDTH
+#define out_height HEIGHT
+#endif
+  height = (u_short)((1.0 - pct) * out_height);
+  r.x = out_width-PB_WIDTH;
+  r.y = out_height-height;
+  r.w = PB_WIDTH;
+  r.h = height;
+
+  SDL_FillRect(drv.sc, &r, color);
+}
+
+
 void
 run(Context_t *ctx)
 {
