@@ -44,10 +44,3 @@ SDL_state drv;
       (void)SDL_Flip(st.sc);			\
   } while(0)
 
-
-void ttf_init();
-void ttf_quit();
-
-void osd(const Context_t *);
-void osd_random_mode_elapsed(const Context_t *);
-
