@@ -20,6 +20,7 @@
 #include <GL/gl.h>
 #include <arpa/inet.h>
 #include "context.h"
+#include "erlang.h"
 
 /*
  * Protocol v3:
@@ -90,4 +91,7 @@ v3(const Context_t *ctx)
   src = export_RGB_active_buffer(ctx, 0);
   ret = write_exact(src, BUFFSIZE*3*sizeof(Pixel_t));
   xfree(src);
+
+  /* XXX keep gcc happy */
+  ret++; /* remove this !*/
 }
