@@ -17,7 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
-// #include <arpa/inet.h>
+#include <arpa/inet.h>
 #include "context.h"
 #include "pnglite.h"
 
@@ -34,7 +34,7 @@ static GByteArray *png_bin = NULL;
 
 
 static unsigned
-png_write_callback(void* input, size_t size, size_t numel, void* user_pointer)
+png_write_callback(void* input, size_t size, size_t numel, __attribute__ ((unused)) void *user_pointer)
 {
   g_byte_array_append(png_bin, input, (size*numel));
   png_size += size*numel;
