@@ -50,6 +50,9 @@ v6(const Context_t *ctx)
   src = export_RGB_active_buffer(ctx, 1);
   ret = write_exact((const u_char *)src, sizeof(u_char)*BUFFSIZE*3);
   xfree(src);
+
+  /* XXX keep gcc happy */
+  ret++; /* <- remove this ! */
 }
 
 
