@@ -42,7 +42,6 @@ v7_send_event(const Event_t *e)
 {
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
-  Pixel_t *src;
   u_char val;
   int ret;
 
@@ -63,6 +62,9 @@ v7_send_event(const Event_t *e)
   ret = write_exact(&val, sizeof(u_char));
   val = e->arg0;
   ret = write_exact(&val, sizeof(u_char));
+
+  /* XXX keep gcc happy */
+  ret++; /* <- remove this ! */
 }
 
 
@@ -84,7 +86,6 @@ v7_send_id(const u_char what, const uint32_t id)
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
   uint32_t id2;
-  Pixel_t *src;
   u_char val;
   int ret;
 
@@ -104,6 +105,9 @@ v7_send_id(const u_char what, const uint32_t id)
 
   id2 = htonl(id);
   ret = write_exact((const u_char *)&id2, sizeof(uint32_t));
+
+  /* XXX keep gcc happy */
+  ret++; /* <- remove this ! */
 }
 
 
@@ -113,7 +117,6 @@ v7_send_sequence(Sequence_t *seq)
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
   uint32_t id, id2;
-  Pixel_t *src;
   u_char val;
   int ret;
   GList *tmp;
@@ -167,6 +170,9 @@ v7_send_sequence(Sequence_t *seq)
 
     tmp = g_list_next(tmp);
   }
+
+  /* XXX keep gcc happy */
+  ret++; /* <- remove this ! */
 }
 
 
