@@ -326,7 +326,7 @@ gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const
 
   srcStride[0] = width;
   dstStride[0] = WIDTH;
-  srcSlice[0] = (char *)grey_data;
+  srcSlice[0] = (uint8_t *)grey_data;
   dst[0] = grey_to;
 
   ret = sws_scale(sws_context, (const uint8_t * const *)srcSlice, srcStride, 0, height, dst, dstStride);
