@@ -18,6 +18,8 @@
  */
 
 #include "main.h"
+#include "webcam.h"
+
 
 static void
 usage()
@@ -40,6 +42,7 @@ usage()
 #endif
 	 "\t-p, --pidfile <file>\tSet the PID file\n"
 	 "\t-t, --themes <themes>\tComma-separated list of themes to use\n"
+	 "\t-c, --camflip <h|v>\tFlip webcam image horizontally/vertically\n"
 	 "\n"
 	 "%s was compiled with:\n"
 	 "\tInput plugins: %s [default: %s]\n"
@@ -54,6 +57,8 @@ usage()
 }
 
 
+extern int hflip, vflip;
+
 void
 getargs(int argc, char **argv)
 {
@@ -79,29 +84,27 @@ getargs(int argc, char **argv)
 		  {"version", no_argument, NULL, 'v'},
 		  {"pidfile", required_argument, NULL, 'p'},
 		  {"themes", required_argument, NULL, 't'},
+		  {"camflip", required_argument, NULL, 'c'},
 		  {0, 0, 0, 0}
 	  };
 
   
   /* Get command line arguments */
-#ifdef FIXED
-  while ((ch = getopt_long(argc, argv, "b:d:fhi:m:o:p:r:s:t:v", long_opt, NULL)) != -1)
+  while ((ch = getopt_long(argc, argv, "b:c:d:fhi:m:o:p:r:s:t:x:y:v", long_opt, NULL)) != -1)
 #else
-  while ((ch = getopt_long(argc, argv, "b:d:fhi:m:o:p:r:s:t:x:y:v", long_opt, NULL)) != -1)
-#endif
-#else
-#ifdef FIXED
-  while ((ch = getopt(argc, argv, "b:d:fhi:m:o:p:r:s:t:v")) != -1)
-#else
-  while ((ch = getopt(argc, argv, "b:d:fhi:m:o:p:r:s:t:x:y:v")) != -1)
-#endif
+  while ((ch = getopt(argc, argv, "b:c:d:fhi:m:o:p:r:s:t:x:y:v")) != -1)
 #endif
     switch (ch) {
     case 'b':
       if (base_dir == NULL)
 	base_dir = optarg;
       break;
-			
+
+    case 'c':
+      if (*optarg == 'h') hflip=!hflip;
+      if (*optarg == 'v') vflip=!vflip;
+      break;
+
     case 'd':
       if (data_dir == NULL)
 	data_dir = optarg;
@@ -170,17 +173,23 @@ getargs(int argc, char **argv)
       exit(0);
       break;
 
-#ifndef FIXED
     case 'x':
+#ifndef FIXED
       width = xatol(optarg);
       printf("[c] Width set to %i\n", width);
+#else
+      fprintf(stderr, "[!] Compiled with fixed buffers, ignoring width= %li\n", xatol(optarg));
+#endif
       break;
 
     case 'y':
+#ifndef FIXED
       height = xatol(optarg);
       printf("[c] Height set to %i\n", height);
-      break;
+#else
+      fprintf(stderr, "[!] Compiled with fixed buffers, ignoring height= %li\n", xatol(optarg));
 #endif
+      break;
 		  
     case 'p':
       if (pid_file == NULL)
