@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -47,7 +47,7 @@ Colormaps_new(const char *directoryname)
   DIR *dir;
   struct dirent *entry;
   GSList *tmp = NULL;
-  u_short size = 0;
+  uint16_t size = 0;
   GSList *t;
   PBar_t *pb = NULL;
     
@@ -65,7 +65,7 @@ Colormaps_new(const char *directoryname)
     pb = pbar_new();
 
   while ((entry = readdir(dir)) != NULL) {
-    long hash;
+    uint32_t hash;
     Cmap8_t *map;
     char *filename;
     const char *sentry = entry->d_name;
@@ -125,7 +125,7 @@ Colormaps_new(const char *directoryname)
     printf("done.\n[c] Loaded %d colormaps\n", size);
 
   if (size) {
-    u_short i;
+    uint16_t i;
 
     colormaps->cmaps = xcalloc(size, sizeof(Cmap8_t *));
     for (i = 0, t = tmp;
@@ -157,7 +157,7 @@ void
 Colormaps_delete()
 {
   if (colormaps != NULL) {
-    u_short i;
+    uint16_t i;
 
     for (i = 0; i < colormaps->size; i++)
       Cmap8_delete(colormaps->cmaps[i]);
@@ -168,9 +168,9 @@ Colormaps_delete()
 
 
 const char *
-Colormaps_name(const long id)
+Colormaps_name(const uint32_t id)
 {
-  u_short i;
+  uint16_t i;
   
   assert(colormaps != NULL);
   
@@ -187,10 +187,10 @@ Colormaps_name(const long id)
 }
 
 
-int
-Colormaps_index(const long id)
+int32_t
+Colormaps_index(const uint32_t id)
 {
-  u_short i;
+  uint16_t i;
   
   assert(colormaps != NULL);
   
@@ -204,10 +204,10 @@ Colormaps_index(const long id)
 }
 
 
-long
+int32_t
 Colormaps_find(const char *name)
 {
-  u_short i;
+  uint16_t i;
 
   assert(colormaps != NULL); /* should have at least a grayscale colormap */
 
@@ -220,10 +220,10 @@ Colormaps_find(const char *name)
 }
 
 
-long
+uint32_t
 Colormaps_random_id()
 {
-  uint32_t idx = 0;
+  uint16_t idx = 0;
 
   assert(colormaps != NULL);
   
