@@ -60,9 +60,16 @@ extern unsigned short WIDTH, HEIGHT;
 
 /* OSD */
 enum OSDMode { OSD_NONE=0, OSD_MINI, OSD_FULL, OSD_FULL_BG };
+#define OSD_FONT   "/usr/share/fonts/truetype/freefont/FreeMono.ttf"
+#define OSD_PTSIZE 14
+#define OSD_BUFFLEN 512
 
 #define SAVEDIR ".lebiniou/sequences"
 
 #define PB_WIDTH 10 /* progress bars width */
 
+#define MAX_BANKS 12
+
+#define ZMAX 5.0
+
 #endif /* __BINIOU_CONSTANTS_H */
