@@ -33,6 +33,7 @@
 static void
 Context_open_webcam(Context_t *ctx)
 {
+#if HAVE_LINUX_VIDEODEV2_H
   fd = -1;
 
   pthread_mutex_init(&ctx->cam_mtx, NULL);
@@ -47,6 +48,7 @@ Context_open_webcam(Context_t *ctx)
 
   if (ctx->has_cam)
     pthread_create(&thr, NULL, loop, (void *)ctx);
+#endif
 }
 
 
@@ -65,10 +67,15 @@ Context_new()
       printf("%d ", i);
     ctx->buffers[i] = Buffer8_new();
   }
-  ctx->cam_ref = Buffer8_new();
   for (i = 0; i < CAM_SAVE; i++)
     ctx->cam_save[i] = Buffer8_new();
-  printf("\n");
+  ctx->rgba_buffers[ACTIVE_BUFFER] = BufferRGBA_new();
+  if (libbiniou_verbose)
+    printf("\n");
+
+#if WITH_GL
+  glGenTextures(NSCREENS, ctx->textures); // TODO: delete on exit
+#endif
 
   if (pictures != NULL) {
     if (libbiniou_verbose)
@@ -97,6 +104,8 @@ Context_new()
     printf("[+] Initializing sequence manager\n");
   ctx->sm = SequenceManager_new();
 
+  Context_load_banks(ctx);
+
   if (libbiniou_verbose)
     printf("[+] Initializing 3D engine\n");
   Params3d_init(&ctx->params3d);
@@ -119,18 +128,40 @@ Context_new()
 
   Context_open_webcam(ctx);
 
+#ifdef FEAT_TARGET
+  ctx->target = 1; /* maybe someday we want a switch to disable,
+		      or worse, a global variable :) */
+  ctx->target_pic = Picture8_new();
+  /* FIXME temp */
+  {
+    extern char *data_dir;
+    gchar *tmp;
+    int res;
+
+    tmp = g_strdup_printf("%s/%s", data_dir, "/images/zebulon/z-biniou-tv-1.png");
+    printf("[+] Loading '%s'\n", tmp);
+    res = Picture8_load_PNG(ctx->target_pic, tmp);
+    assert(!res);
+    if (res == -1)
+      xerror("Picture8_load_PNG(%s)\n", tmp);
+    g_free(tmp);
+  }
+#endif
+
   return ctx;
 }
 
 
 static void
-Context_close_webcam(Context_t *ctx)
+Context_close_webcam(__attribute__ ((unused)) Context_t *ctx)
 {
+#if HAVE_LINUX_VIDEODEV2_H
   pthread_join(thr, NULL);
   stop_capturing();
   uninit_device();
   close_device();
   free(dev_name);
+#endif
 }
 
 
@@ -163,9 +194,9 @@ Context_delete(Context_t *ctx)
       printf("%d ", i);
     Buffer8_delete(ctx->buffers[i]);
   }
-  Buffer8_delete(ctx->cam_ref);
   for (i = 0; i < CAM_SAVE; i++)
     Buffer8_delete(ctx->cam_save[i]);
+  BufferRGBA_delete(ctx->rgba_buffers[ACTIVE_BUFFER]);
   if (libbiniou_verbose)
     printf("\n");
 
@@ -194,6 +225,11 @@ Context_delete(Context_t *ctx)
   b_timer_delete(ctx->timer);
   b_timer_delete(ctx->fps_timer);
 
+#ifdef FEAT_TARGET
+  if (NULL != ctx->target_pic)
+    Picture8_delete(ctx->target_pic);
+#endif
+
   xfree(ctx);
 }
 
@@ -513,14 +549,16 @@ Context_set_sequence(Context_t *ctx, const uint32_t id)
 
 
 void
-Context_use_bank(Context_t *ctx, const u_char bank)
+Context_use_sequence_bank(Context_t *ctx, const u_char bank)
 {
   u_long id;
 
-  id = ctx->sm->banks[ctx->sm->cur_bankset][bank];
+  id = ctx->banks[SEQUENCES][ctx->bankset[SEQUENCES]][bank];
   if (id) {
     Sequence_t *seq;
 
+    printf("[i] Using sequence in bank #%d\n", (bank+1));
+
     if (libbiniou_verbose)
       printf("[s] Set sequence: %li\n", id);
 
@@ -532,18 +570,18 @@ Context_use_bank(Context_t *ctx, const u_char bank)
     ctx->sm->curseq = seq->layers;
     Sequence_copy(seq, ctx->sm->next);
 
-    ctx->bank = bank; /* ca sert a quoi de garder ctx->bank ? --oliv3 */
+    ctx->bank[SEQUENCES] = bank;
 
     Context_set(ctx);
   } else
-    printf("[i] Bank %d/%d is empty\n", ctx->sm->cur_bankset+1, bank+1);
+    printf("[i] Bank %d/%d is empty\n", ctx->bankset[SEQUENCES]+1, bank+1);
 }
 
 
 void
 Context_clear_bank(Context_t *ctx, const u_char bank)
 {
-  ctx->sm->banks[ctx->sm->cur_bankset][bank] = 0;
+  ctx->banks[ctx->bank_mode][ctx->bankset[ctx->bank_mode]][bank] = 0;
 }
 
 
