@@ -20,6 +20,9 @@
 #ifndef __BINIOU_CONTEXT_H
 #define __BINIOU_CONTEXT_H
 
+#ifdef WITH_GL
+#include <GL/gl.h>
+#endif
 #include "input.h"
 #include "sequencemanager.h"
 #include "params3d.h"
@@ -28,17 +31,19 @@
 #include "cmapfader.h"
 #include "alarm.h"
 #include "brandom.h"
+#include "buffer_RGBA.h"
 
 #define NFPS       25 /* to get mean fps */
 
 enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 
-#define NSCREENS 5
+#define NSCREENS 6
 #define ACTIVE_BUFFER  0
 #define PASSIVE_BUFFER 1
 #define SAVE_BUFFER    2
 #define CAM_IN_BUFFER  3
-#define CAM_OUT_BUFFER 4
+#define CAM_REF_BUFFER 4
+#define CAM_OUT_BUFFER 5
 
 /* store the last N frames from the webcam -same as EffectTV */
 #define CAM_SAVE 32
@@ -57,15 +62,18 @@ typedef struct Context_s {
 
   /* Buffers */
   Buffer8_t *buffers[NSCREENS];
+  BufferRGBA_t *rgba_buffers[NSCREENS];
   /* 0 = active_buffer
    * 1 = passive_buffer - for double-buffering
    * 2 = save_buffer    - push/pop screen for lens effects
    * 3 = camera input
-   * 4 = camera output
+   * 4 = camera reference
+   * 5 = camera output
    */
 
   /* webcam */
-  Buffer8_t *cam_save[CAM_SAVE], *cam_ref;
+  Buffer8_t *cam_save[CAM_SAVE];
+  char ref_taken:1;
 
   /* Faders */
   PictFader_t *pf;
@@ -106,12 +114,30 @@ typedef struct Context_s {
 
   void (*events_cb)(struct Context_s *, const BKey_t *); /* events callback */
 
-  u_char   bank; /* the bank used */
+  /* Banks */
+  u_char   bank_mode; /* will default to SEQUENCES */
+  uint32_t banks[3][MAX_BANKS][MAX_BANKS];
+  u_char   bankset[3];
+  u_char   bank[3]; /* the bank used */
 
   /* Webcam */
   u_char has_cam;
   pthread_mutex_t cam_mtx;
   u_char cam;
+
+  /* OpenGL */
+#ifdef WITH_GL
+  char texture_ready:1;
+  char texture_used:1;
+  char gl_done:1;
+  GLuint textures[NSCREENS];
+#endif
+
+  /* Target */
+#ifdef FEAT_TARGET
+  char       target:1;
+  Picture8_t *target_pic;
+#endif
 } Context_t;
 
 
@@ -185,15 +211,21 @@ pop_buffer(const Context_t *ctx)
 }
 
 
-Pixel_t *
-export_RGB_buffer(const Context_t *, const u_char, const u_char);
+/* TODO: deprecate export_RGB*, use export RGBA* */
+Pixel_t *export_RGB_buffer(const Context_t *, const u_char, const u_char);
+Pixel_t *export_RGB_active_buffer(const Context_t *, const u_char);
+const RGBA_t *export_RGBA_buffer(const Context_t *, const u_char);
+const RGBA_t *export_RGBA_active_buffer(const Context_t *);
 
-Pixel_t *
-export_RGB_active_buffer(const Context_t *, const u_char);
-
-void Context_use_bank(Context_t *, const u_char);
+void Context_save_banks(const Context_t *);
+void Context_load_banks(Context_t *);
+void Context_use_sequence_bank(Context_t *, const u_char);
 void Context_clear_bank(Context_t *, const u_char);
+void Context_store_bank(Context_t *, const u_char);
+void Context_use_bankset(Context_t *, const u_char);
 
 void Context_push_webcam(Context_t *, Buffer8_t *);
 
+void Context_make_GL_texture(Context_t *ctx, const u_char);
+
 #endif /* __BINIOU_CONTEXT_H */
