@@ -360,13 +360,38 @@ Context_event(Context_t *ctx, const Event_t *e)
     }
 
   case BC_USE_BANK:
-    printf("[i] Using sequence in bank #%d\n", (e->arg0+1));
-    Context_use_bank(ctx, e->arg0);
+    switch (ctx->bank_mode) {
+    case SEQUENCES:
+      Context_use_sequence_bank(ctx, e->arg0);
+      break;
+    case COLORMAPS:
+      {
+	uint32_t id = ctx->banks[COLORMAPS][ctx->bankset[COLORMAPS]][e->arg0];
+	if (id) {
+	  printf("[i] Using colormap in bank #%d\n", (e->arg0+1));
+	  ctx->sm->next->cmap_id = id;
+	  ctx->bank[COLORMAPS] = e->arg0;
+	  Context_set_colormap(ctx);
+	}
+      }
+      break;
+    case PICTURES:
+      {
+	uint32_t id = ctx->banks[PICTURES][ctx->bankset[PICTURES]][e->arg0];
+	if (id) {
+	  printf("[i] Using picture in bank #%d\n", (e->arg0+1));
+	  ctx->sm->next->picture_id = id;
+	  ctx->bank[PICTURES] = e->arg0;
+	  Context_set_picture(ctx);
+	}
+      }
+      break;
+    }
     return 1;
     break;
 
   case BC_CLEAR_BANK:
-    printf("[i] Clear sequence in bank #%d\n", (e->arg0+1));
+    printf("[i] Clear sequence/colormap/picture in bank #%d\n", (e->arg0+1));
     Context_clear_bank(ctx, e->arg0);
     return 1;
     break;
@@ -381,12 +406,43 @@ Context_event(Context_t *ctx, const Event_t *e)
   case BC_SET:
     if (e->arg0 == BA_WEBCAM) {
       pthread_mutex_lock(&ctx->cam_mtx);
-      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->cam_ref);
+      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->buffers[CAM_REF_BUFFER]);
       pthread_mutex_unlock(&ctx->cam_mtx);
       return 1;
     }
     break;
 
+  case BC_STORE_BANK:
+    printf("[i] Storing sequence/colormap/picture in bank #%d\n", e->arg0+1);
+    Context_store_bank(ctx, e->arg0);
+    return 1;
+    break;
+
+  case BC_USE_BANKSET:
+    printf("[i] Using bankset %d\n", (e->arg0+1));
+    Context_use_bankset(ctx, e->arg0);
+    return 1;
+    break;
+
+  case BC_SAVE_BANKS:
+    printf("[i] Writing banks file\n");
+    Context_save_banks(ctx);
+    return 1;
+    break;
+
+  case BC_SET_BANKMODE:
+    printf("[i] Set bank mode to ");
+    switch (e->arg0) {
+    case SEQUENCES: printf("sequences"); break;
+    case COLORMAPS: printf("colormaps"); break;
+    case PICTURES: printf("pictures"); break;
+    default: xerror("Invalid bank mode %d\n", e->arg0); break;
+    }
+    printf("\n");
+    ctx->bank_mode = e->arg0;
+    return 1;
+    break;
+
   default:
     break;
   }
