@@ -30,7 +30,7 @@ export_RGB_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
   u_long c, i=0;
 
   if (flip)
-    Buffer8_flip_x(buf);
+    Buffer8_flip_v(buf);
   src = buf->buffer;
 
   res = xmalloc(3*BUFFSIZE*sizeof(Pixel_t));
@@ -42,7 +42,7 @@ export_RGB_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
   }
 
   if (flip)
-    Buffer8_flip_x(buf);
+    Buffer8_flip_v(buf);
 
   return res;
 }
@@ -53,3 +53,27 @@ export_RGB_active_buffer(const Context_t *ctx, const u_char flip)
 {
   return export_RGB_buffer(ctx, ACTIVE_BUFFER, flip);
 }
+
+
+const RGBA_t *
+export_RGBA_buffer(const Context_t *ctx, const u_char screen)
+{
+  rgba_t *colors = &ctx->cf->cur->colors[0];
+  Pixel_t *src = ctx->buffers[screen]->buffer, *start;
+  RGBA_t *dst = ctx->rgba_buffers[screen]->buffer;
+
+  assert(NULL != dst);
+  start = src;
+
+  for ( ; src < start+BUFFSIZE*sizeof(Pixel_t); src++, dst++)
+    *dst = colors[*src].col;
+
+  return ctx->rgba_buffers[screen]->buffer;
+}
+
+
+const RGBA_t *
+export_RGBA_active_buffer(const Context_t *ctx)
+{
+  return export_RGBA_buffer(ctx, ACTIVE_BUFFER);
+}
