@@ -17,6 +17,10 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef WITH_GL
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
 #include "biniou.h"
 #include "schemes.h"
 #include "pictures.h"
@@ -67,10 +71,15 @@ static void
 Context_sequence(Context_t *ctx)
 {
   const GList *tmp;
+  uint16_t count = 0;
 
   tmp = ctx->sm->cur->layers;
   b_timer_start(ctx->fps_timer);
 
+#ifdef WITH_GL
+  ctx->texture_ready = ctx->texture_used = ctx->gl_done = 0;
+#endif
+
   while (tmp != NULL) {
     Layer_t *layer = (Layer_t *)tmp->data;
     Plugin_t *P = layer->plugin;
@@ -83,6 +92,7 @@ Context_sequence(Context_t *ctx)
       if (!ctx->bypass || (ctx->bypass && !(*P->options & BEQ_BYPASS))) {
 	P->run(ctx);
 	P->calls++;
+	count++;
       }
 
     switch (layer->mode) {
@@ -116,6 +126,12 @@ Context_sequence(Context_t *ctx)
 
     tmp = g_list_next(tmp);
   }
+#ifdef FEAT_TARGET
+  if (!count && ctx->target) {
+    assert(NULL != ctx->target_pic);
+    Buffer8_copy(ctx->target_pic->buff, active_buffer(ctx));
+  }
+#endif
 }
 
 
@@ -189,6 +205,36 @@ Context_run(Context_t *ctx)
   Params3d_init_z_buffer();
 #endif
 
+#ifdef WITH_GL
+  glClearColor(0, 0, 0, 0);
+  glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT);
+
+  /* Initialize projection matrix */
+  glMatrixMode(GL_PROJECTION);
+  glLoadIdentity();
+
+  gluPerspective(ctx->params3d.gl_fov, (float)WIDTH/(float)HEIGHT,
+		 0.1, ZMAX);
+  gluLookAt(0, 0, 3.14,
+	    0, 0, -3.14,
+	    0, 1, 0);
+
+  glShadeModel(GL_SMOOTH);
+
+  glClearDepth(ZMAX),
+  glEnable(GL_DEPTH_TEST);
+  glDepthFunc(GL_LEQUAL);
+
+  glEnable(GL_BLEND);
+
+  glRotatef(ctx->params3d.gl_rotations[0], 1.0, 0.0, 0.0);
+  glRotatef(ctx->params3d.gl_rotations[1], 0.0, 1.0, 0.0);
+  glRotatef(ctx->params3d.gl_rotations[2], 0.0, 0.0, 1.0);
+
+  glMatrixMode(GL_MODELVIEW);
+  glLoadIdentity();
+#endif
+
   /* The sequence */
   Context_sequence(ctx);
 
