@@ -25,6 +25,8 @@
 #define PLUGINS "Plugins"
 #define SCREEN  "Screen"
 #define ENGINE  "Engine"
+#define INPUT   "Input"
+#define WEBCAM  "Webcam"
 
 /*
    [Plugins]
@@ -41,10 +43,17 @@
    OSD=0
    RandomMode=2
    Fps=60
+
+   [Input]
    AntiPhase=false
+
+   [Webcam]
+   HorizontalFlip=false
+   VerticalFlip=false
 */
 
 extern float phase;
+extern int hflip, vflip;
 
 
 static void
@@ -53,7 +62,10 @@ process(GKeyFile *kf)
   GError *error = NULL;
   gchar *input = NULL, *output = NULL, *kf_themes = NULL;
   gchar fs = FALSE, antiphase = FALSE;
+  gchar whflip = FALSE, wvflip = FALSE;
+#ifndef FIXED
   gint kf_width, kf_height;
+#endif
   gint kf_fps, kf_osd, kf_rnd;
 
   input = g_key_file_get_string(kf, PLUGINS, "Input", NULL);
@@ -147,7 +159,7 @@ process(GKeyFile *kf)
     printf("[k] Setting themes to: %s\n", themes);
   }
 
-  antiphase = g_key_file_get_boolean(kf, ENGINE, "AntiPhase", &error);
+  antiphase = g_key_file_get_boolean(kf, INPUT, "AntiPhase", &error);
   if (NULL == error) {
     if (antiphase == TRUE) {
       phase = -1.0;
@@ -157,6 +169,28 @@ process(GKeyFile *kf)
     g_error_free(error);
     error = NULL;
   }
+
+  whflip = g_key_file_get_boolean(kf, WEBCAM, "HorizontalFlip", &error);
+  if (NULL == error) {
+    if (whflip == TRUE) {
+      printf("[k] Setting webcam horizontal flip\n");
+      hflip = !hflip;
+    }
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
+  wvflip = g_key_file_get_boolean(kf, WEBCAM, "VerticalFlip", &error);
+  if (NULL == error) {
+    if (wvflip == TRUE) {
+      printf("[k] Setting webcam vertical flip\n");
+      vflip = !vflip;
+    }
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
 }
 
 
