@@ -34,7 +34,8 @@ enum RandomMode random_mode = BR_SCHEMES;
 enum OSDMode osd_mode = OSD_NONE;
 char *pid_file = NULL;
 char *themes = NULL;
-
+int hflip = 1;
+int vflip = 1;
 
 #define _BANNER "\n"					\
   "      _          ___ _      _          \n"		\
