@@ -99,6 +99,10 @@ Params3d_init(Params3d_t *p)
 
   p->xs = p->xe = HWIDTH;
   p->ys = p->ye = HHEIGHT;
+#ifdef WITH_GL
+  p->gl_xs = p->gl_xe = HWIDTH;
+  p->gl_ys = p->gl_ye = HHEIGHT;
+#endif
 
   init_sphere_3d();
   zero_3d(p);
@@ -114,6 +118,10 @@ Params3d_init(Params3d_t *p)
   p->rotate_amount[X_AXIS] = 1 * ROT_STEP;
   p->rotate_amount[Y_AXIS] = 2 * ROT_STEP;
   p->rotate_amount[Z_AXIS] = 4 * ROT_STEP;
+
+#ifdef WITH_GL
+  p->gl_fov = 50;
+#endif
 }
 
 
@@ -213,7 +221,8 @@ Params3d_rotate(Params3d_t *p)
   float dy = (p->ye-p->ys)/(float)(HEIGHT/8);
 
   /* printf ("dx= %f, dy= %f\n", dx, dy); */
-	
+
+  // BUGGY (Y/X) then check (X/Z)?!
   p->rotations[Y_AXIS] += dx;
   p->rotations[X_AXIS] += dy;
 	
@@ -234,6 +243,32 @@ Params3d_rotate(Params3d_t *p)
 }
 
 
+void
+Params3d_rotate_GL(Params3d_t *p)
+{
+  float dx = (p->gl_xe-p->gl_xs)/(float)(WIDTH/8);
+  float dy = (p->gl_ye-p->gl_ys)/(float)(HEIGHT/8);
+
+  // printf ("dx= %f, dy= %f\n", dx, dy);
+	
+  p->gl_rotations[Y_AXIS] += dx*15;
+  p->gl_rotations[X_AXIS] += dy*15;
+	
+  if (p->gl_rotations[Y_AXIS] > 360)
+    p->gl_rotations[Y_AXIS] -= 360;
+  else if (p->gl_rotations[Y_AXIS] < -360)
+    p->gl_rotations[Y_AXIS] += 360;
+	
+  if (p->rotations[X_AXIS] > 360)
+    p->rotations[X_AXIS] -= 360;
+  else if (p->rotations[X_AXIS] < -360)
+    p->rotations[X_AXIS] += 360;
+	
+  p->gl_xs = p->gl_xe;
+  p->gl_ys = p->gl_ye;
+}
+
+
 void
 Params3d_change_rotations(Params3d_t *p)
 {
