@@ -40,12 +40,17 @@ typedef struct Params3d_s {
   u_char  do_auto_rotate;
   u_char  auto_rotate[3];
   float   rotate_amount[3];
-  float   rotations[3]; /* TODO precompute ? */
+  float   rotations[3];
   float   Cos[3]; /* TODO precompute 360 deg */
   float   Sin[3]; /* TODO precompute 360 deg */
   u_char  draw_boundary; /* for 3D objects */
   int     xs, ys; /* to handle drag/drop 3D rotations */
   int     xe, ye;
+  /* OpenGL */
+  float   gl_rotations[3];
+  int     gl_xs, gl_ys;
+  int     gl_xe, gl_ye;
+  float   gl_fov;
 } Params3d_t;
 
 
@@ -214,6 +219,7 @@ void draw_sphere_wireframe_3d(const Params3d_t *, Buffer8_t *, const Pixel_t);
 void draw_line_3d(const Params3d_t *, Buffer8_t *, const Point3d_t *, const Point3d_t *, const Pixel_t);
 
 void Params3d_rotate(Params3d_t *);
+void Params3d_rotate_GL(Params3d_t *);
 void Params3d_change_rotations(Params3d_t *);
 
 #ifdef Z_BUFFER
