@@ -117,7 +117,7 @@ PNG_to_Y(const png_t *png, const u_char *src)
 }
 
 
-static int
+int
 Picture8_load_PNG(Picture8_t *pic, const char *filename)
 {
   png_t png;
@@ -150,7 +150,7 @@ Picture8_load_PNG(Picture8_t *pic, const char *filename)
 	xfree(pic->buff->buffer);
 	pic->buff->buffer = y;
       }
-      Buffer8_flip_x(pic->buff);
+      Buffer8_flip_v(pic->buff);
     } else {
       static int verbose = 1;
 
