@@ -36,7 +36,7 @@ void Pictures_delete();
 
 const char *Pictures_name(const uint32_t);
 int32_t Pictures_index(const uint32_t);
-int32_t Pictures_find(const char *);
+uint32_t Pictures_find(const char *);
 uint32_t Pictures_random_id();
 const Picture8_t *Pictures_random();
 
