@@ -17,6 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <inttypes.h>
 #include "biniou.h"
 #include "plugin.h"
 
@@ -248,12 +249,12 @@ Plugin_on_key(const uint32_t id, const u_char k)
   Plugin_t *p = Plugins_find(id);
 
   if (NULL == p) {
-    printf("[!] Plugin id %li not found\n", id);
+    printf("[!] Plugin id %"PRIu32" not found\n", id);
     return;
   }
 
   if (NULL == p->on_key) {
-    printf("[!] Plugin id %li has no on_key callback\n", id);
+    printf("[!] Plugin id %"PRIu32" has no on_key callback\n", id);
     return;
   } else
     p->on_key(k);
