@@ -113,13 +113,12 @@ Plugins_select(Plugins_t *ps, const Plugin_t *p)
 {
   short i;
 
-  for (i = 0; i < ps->size; i++) {
+  for (i = 0; i < ps->size; i++)
     if (ps->plugins[i] == p) {
       ps->selected_idx = i;
       ps->selected = (Plugin_t *)p;
       return;
     }
-  }
 
   xerror("Plugins_select failed");
 }
@@ -263,6 +262,7 @@ Plugins_next()
       plugins->selected_idx = 0;
     plugins->selected = plugins->plugins[plugins->selected_idx];
   } while (*plugins->selected->options & BEQ_DISABLED);
+  printf("[i] Selected plugin: %s\n", plugins->selected->name);
 }
 
 
@@ -274,6 +274,7 @@ Plugins_prev()
       plugins->selected_idx = plugins->size-1;
     plugins->selected = plugins->plugins[plugins->selected_idx];
   } while (*plugins->selected->options & BEQ_DISABLED);
+  printf("[i] Selected plugin: %s\n", plugins->selected->name);
 }
 
 
