@@ -25,8 +25,10 @@
 #include <linux/videodev2.h>
 #endif
 
+#ifndef CAPTURE_SET
 #define CAP_WIDTH  640
 #define CAP_HEIGHT 480
+#endif /* CAPTURE_SET */
 
 #define CLEAR(x) memset(&(x), 0, sizeof(x))
 
@@ -46,10 +48,9 @@ struct buffer {
 
 /* options */
 char *dev_name;
-int flip;
 
 int fd;
-static io_method io = IO_METHOD_MMAP;
+io_method io;
 unsigned int n_buffers;
 struct buffer *buffers;
 
@@ -68,17 +69,6 @@ void stop_capturing();
 void uninit_device();
 void close_device();
 
-
-static int
-xioctl(int fd, int request, void *arg)
-{
-  int r;
-
-  do
-    r = ioctl(fd, request, arg);
-  while ((-1 == r) && (EINTR == errno));
-
-  return r;
-}
+int xioctl(int, int, void *);
 
 #endif /* __WEBCAM_H */
