@@ -20,6 +20,21 @@
 #include "webcam.h"
 
 
+io_method io = IO_METHOD_MMAP;
+
+int
+xioctl(int fd, int request, void *arg)
+{
+  int r;
+
+  do
+    r = ioctl(fd, request, arg);
+  while ((-1 == r) && (EINTR == errno));
+
+  return r;
+}
+
+
 void
 init_read(unsigned int buffer_size)
 {
