@@ -19,6 +19,8 @@
 
 #include "webcam.h"
 
+extern int hflip, vflip;
+
 
 static void
 process_image(Context_t *ctx, void *p)
@@ -48,8 +50,11 @@ process_image(Context_t *ctx, void *p)
   else
     gray_scale(dst->buffer, CAP_WIDTH, CAP_HEIGHT, temp);
 
-  if (flip)
-    Buffer8_flip_x(dst);
+  if (hflip)
+    Buffer8_flip_h(dst);
+
+  if (vflip)
+    Buffer8_flip_v(dst);
 
   Context_push_webcam(ctx, save);
   pthread_mutex_unlock(&ctx->cam_mtx);
@@ -157,7 +162,6 @@ void *
 loop(void *args)
 {
   Context_t *ctx = (Context_t *)args;
-  static int ref_taken = 0;
 
   while (ctx->running) {
     fd_set fds;
@@ -185,9 +189,9 @@ loop(void *args)
 
     read_frame(ctx);
 
-    if (!ref_taken) {
-      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->cam_ref);
-      ref_taken = 1;
+    if (!ctx->ref_taken) {
+      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->buffers[CAM_REF_BUFFER]);
+      ctx->ref_taken = 1;
     }
   }
 
