@@ -19,6 +19,8 @@
 
 #include "webcam.h"
 
+extern int hflip, vflip;
+
 
 static void
 process_token(const char *tok)
@@ -36,9 +38,12 @@ process_token(const char *tok)
     printf("[i] webcam: device set to %s\n", *vv);
     free(dev_name);
     dev_name = strdup(*vv);
-  } else if (!strcmp((const char *)*vv, "flip")) {
-    printf("[i] webcam: set flip\n");
-    flip = !flip;
+  } else if (!strcmp((const char *)*vv, "hflip")) {
+    printf("[i] webcam: set horizontal flip\n");
+    hflip = !hflip;
+  } else if (!strcmp((const char *)*vv, "vflip")) {
+    printf("[i] webcam: set vertical flip\n");
+    vflip = !vflip;
   }
 
   g_strfreev(varval);
@@ -50,7 +55,7 @@ process_options(const char *options)
 {
   gchar **tokens  = NULL, **tok;
 
-  tokens = g_strsplit(options, " ", 0);
+  tokens = g_strsplit(options, ",", 0);
 
   for (tok = tokens ; *tok != NULL; tok++)
     process_token(*tok);
@@ -65,7 +70,6 @@ parse_options()
   char *options = NULL;
 
   dev_name = strdup(DEFAULT_VIDEO_DEVICE);
-  flip = 1;
 
   options = getenv("BINIOU_WEBCAM");
 
